@@ -1,17 +1,15 @@
-"""Python language extensions.
+"""Python language extensions
 
 This is a transitional project.  Each of these extensions will
 eventually get migrated to its own project.
 
 """
 
+__version__ = "0.2.0"
 __copyright__ = "Copyright (C) 2014 Ivan D Vasin"
-__credits__ = ["Tyler Dumont", "Ivan D Vasin"]
+__credits__ = ["Ivan D Vasin"]
 __maintainer__ = "Ivan D Vasin"
 __email__ = "nisavid@gmail.com"
 __docformat__ = "restructuredtext"
 
-from ._datatypes import *
-from ._exc import *
-from ._functools import *
 from ._misc import *
