@@ -1,4 +1,4 @@
-"""Python language extensions miscellany."""
+"""Python language extensions miscellany"""
 
 __copyright__ = "Copyright (C) 2014 Ivan D Vasin"
 __docformat__ = "restructuredtext"
@@ -7,7 +7,7 @@ import re as _re
 
 
 def safe_name(name, default_str='_'):
-    """Convert a name to a safe object name.
+    """Convert a name to a safe object name
 
     The object name is "safe" in the sense that it consists only of
     characters that are allowed in object names in Python source code.
@@ -27,12 +27,12 @@ def safe_name(name, default_str='_'):
     safe_name_ = _re.sub(r'[^\d\w]', default_str, safe_name_)
     if not safe_name_:
         raise ValueError('cannot convert {!r} to a safe object name'
-                             .format(name))
+                          .format(name))
     return safe_name_
 
 
 def safe_classname(name, default_str='_'):
-    """Convert a name to a safe class name.
+    """Convert a name to a safe class name
 
     This function passes its arguments through :func:`safe_name` and
     converts the result to CamelCase.
@@ -44,5 +44,5 @@ def safe_classname(name, default_str='_'):
                         if word)
     if not classname:
         raise ValueError('cannot convert {!r} to a safe class name'
-                             .format(name))
+                          .format(name))
     return classname
